@@ -26,31 +26,25 @@ def check() -> None:
         print_cross_message(f'Vault backend failed from: {address()}', leave=True)
 
 
-@cli.command(help='Create client state and vault path.')
+@cli.command(help='Create client vault state.')
 def create() -> None:
-    click.secho('- Create client state', fg='green')
+    click.secho('- Create client vault state', fg='green')
     create_state()
 
 
-@cli.command(help='Update client state.')
-@click.option('--config-type', required=True, type=click.Choice(['TERRAFORM', 'ANSIBLE'], case_sensitive=True),
-              help='Choose required configuration framework')
-def update(config_type) -> None:
-    click.secho(f'- Update client state for config {config_type}', fg='green')
+@cli.command(help='Load client state from vault.')
+def load() -> None:
+    click.secho('- Load client state from vault', fg='green')
+    load_state()
+
+
+@cli.command(help='Save client state.')
+def save() -> None:
+    click.secho('- Save client vault state', fg='green')
     state = load_state()
     tfstate_content = state.tfstate()
     create_tfstate(state, tfstate_content)
 
 
-@cli.command(help='Save client state.')
-def save() -> None:
-    click.secho('- Save client state', fg='green')
-
-
-@cli.command(help='Load client state.')
-def fetch() -> None:
-    click.secho('- Load client state', fg='green')
-
-
 if __name__ == '__main__':
     exit(cli())
